@@ -8,6 +8,26 @@
 # Local application imports
 import common.hstr as _hstr
 
+def ecb_encryption(enc, key, block):
+    """ecb_encryption()
+    """
+    ciphertext = ''
+    for i in range(len(block)//16):
+        plaintext = block[i*16:(i+1)*16]
+        ciphertext += enc(key, plaintext)
+
+    return ciphertext
+
+def ecb_decryption(dec, key, block):
+    """ecb_decryption()
+    """
+    plaintext = ''
+    for i in range(len(block)//16):
+        ciphertext = block[i*16:(i+1)*16]
+        plaintext += dec(key, ciphertext)
+
+    return plaintext
+
 def cbc_encryption(enc, key, block, iv):
     """cbc_encryption()
     """
